@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for GNU Prolog 1.4.2 (and later versions)
-%  Last updated on February 12, 2016
+%  Last updated on May 9, 2016
 %
 %  This file is part of Logtalk <http://logtalk.org/>  
 %  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
@@ -149,8 +149,7 @@ setup_call_cleanup(_, _, _) :-
 
 % '$lgt_prolog_database_predicate'(@callable)
 
-'$lgt_prolog_database_predicate'(_) :-
-	fail.
+'$lgt_prolog_database_predicate'(listing(_)).
 
 
 
