@@ -5,7 +5,7 @@
 %  make/0, and to improve usability when using the XPCE profiler and XPCE
 %  graphical debugger
 %
-%  Last updated on May 29, 2016
+%  Last updated on June 15, 2016
 %
 %  This file is part of Logtalk <http://logtalk.org/>  
 %  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
@@ -191,11 +191,11 @@ user:prolog_predicate_name(Goal, Label) :-
 '$lgt_swi_prolog_predicate_name'('$lgt_threaded_notify'(_, _), 'threaded_notify/1') :- !.
 
 '$lgt_swi_prolog_predicate_name'('$lgt_threaded_engine_create'(_, _, _, _), 'threaded_engine_create/3') :- !.
-'$lgt_swi_prolog_predicate_name'('$lgt_threaded_engine_stop'(_, _), 'threaded_engine_stop/1') :- !.
+'$lgt_swi_prolog_predicate_name'('$lgt_threaded_engine_destroy'(_, _), 'threaded_engine_destroy/1') :- !.
 '$lgt_swi_prolog_predicate_name'('$lgt_threaded_engine_self'(_, _), 'threaded_engine_self/1') :- !.
 '$lgt_swi_prolog_predicate_name'('$lgt_current_engine_'(_, _), 'threaded_engine/1') :- !.
-'$lgt_swi_prolog_predicate_name'('$lgt_threaded_engine_answer'(_, _, _), 'threaded_engine_answer/2') :- !.
-'$lgt_swi_prolog_predicate_name'('$lgt_threaded_engine_return'(_, _), 'threaded_engine_return/1') :- !.
+'$lgt_swi_prolog_predicate_name'('$lgt_threaded_engine_next'(_, _, _), 'threaded_engine_next/2') :- !.
+'$lgt_swi_prolog_predicate_name'('$lgt_threaded_engine_yield'(_, _), 'threaded_engine_yield/1') :- !.
 '$lgt_swi_prolog_predicate_name'('$lgt_threaded_engine_post'(_, _, _), 'threaded_engine_post/2') :- !.
 '$lgt_swi_prolog_predicate_name'('$lgt_threaded_engine_fetch'(_, _), 'threaded_engine_fetch/1') :- !.
 
@@ -499,11 +499,11 @@ user:portray(c(This, Entity, Rest)) :-
 
 '$lgt_swi_unify_clause_body'(threaded_engine_create(Answer, Goal, Engine), Entity, '$lgt_threaded_engine_create'(Answer, TGoal, _, Engine), TermPos0, TermPos) :- !,
 	'$lgt_swi_unify_clause_body'(Goal, Entity, TGoal, TermPos0, TermPos).
-'$lgt_swi_unify_clause_body'(threaded_engine_stop(Engine), _, '$lgt_threaded_engine_stop'(Engine, _), TermPos, TermPos) :- !.
+'$lgt_swi_unify_clause_body'(threaded_engine_destroy(Engine), _, '$lgt_threaded_engine_destroy'(Engine, _), TermPos, TermPos) :- !.
 '$lgt_swi_unify_clause_body'(threaded_engine_self(Engine), _, '$lgt_threaded_engine_self'(Engine, _), TermPos, TermPos) :- !.
 '$lgt_swi_unify_clause_body'(threaded_engine(Engine), _, '$lgt_current_engine_'(Engine, _), TermPos, TermPos) :- !.
-'$lgt_swi_unify_clause_body'(threaded_engine_answer(Engine, Answer), _, '$lgt_threaded_engine_answer'(Engine, Answer, _), TermPos, TermPos) :- !.
-'$lgt_swi_unify_clause_body'(threaded_engine_return(Answer), _, '$lgt_threaded_engine_return'(Answer, _), TermPos, TermPos) :- !.
+'$lgt_swi_unify_clause_body'(threaded_engine_next(Engine, Answer), _, '$lgt_threaded_engine_next'(Engine, Answer, _), TermPos, TermPos) :- !.
+'$lgt_swi_unify_clause_body'(threaded_engine_yield(Answer), _, '$lgt_threaded_engine_yield'(Answer, _), TermPos, TermPos) :- !.
 '$lgt_swi_unify_clause_body'(threaded_engine_post(Engine, Term), _, '$lgt_threaded_engine_post'(Engine, Term, _), TermPos, TermPos) :- !.
 '$lgt_swi_unify_clause_body'(threaded_engine_fetch(Term), _, '$lgt_threaded_engine_fetch'(Term, _), TermPos, TermPos) :- !.
 
@@ -636,11 +636,11 @@ user:portray(c(This, Entity, Rest)) :-
 :- '$set_predicate_attribute'('$lgt_threaded_notify_ctg'/2, trace, 1).
 :- '$set_predicate_attribute'('$lgt_threaded_notify'/2, trace, 1).
 :- '$set_predicate_attribute'('$lgt_threaded_engine_create'/4, trace, 1).
-:- '$set_predicate_attribute'('$lgt_threaded_engine_stop'/2, trace, 1).
+:- '$set_predicate_attribute'('$lgt_threaded_engine_destroy'/2, trace, 1).
 :- '$set_predicate_attribute'('$lgt_threaded_engine_self'/2, trace, 1).
 :- '$set_predicate_attribute'('$lgt_current_engine_'/2, trace, 1).
-:- '$set_predicate_attribute'('$lgt_threaded_engine_answer'/3, trace, 1).
-:- '$set_predicate_attribute'('$lgt_threaded_engine_return'/2, trace, 1).
+:- '$set_predicate_attribute'('$lgt_threaded_engine_next'/3, trace, 1).
+:- '$set_predicate_attribute'('$lgt_threaded_engine_yield'/2, trace, 1).
 :- '$set_predicate_attribute'('$lgt_threaded_engine_post'/3, trace, 1).
 :- '$set_predicate_attribute'('$lgt_threaded_engine_fetch'/2, trace, 1).
 
