@@ -3,7 +3,7 @@
 %  Integration code for YAP 6.3.4 and later versions to improve
 %  usability when using the YAP profilers.
 %
-%  Last updated on May 29, 2016
+%  Last updated on June 15, 2016
 %
 %  This file is part of Logtalk <http://logtalk.org/>  
 %  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
@@ -104,11 +104,11 @@ user:prolog_predicate_name(user:'$lgt_threaded_notify_ctg'(_, _), 'threaded_noti
 user:prolog_predicate_name(user:'$lgt_threaded_notify'(_, _), 'threaded_notify/1') :- !.
 
 user:prolog_predicate_name(user:'$lgt_threaded_engine_create'(_, _, _, _), 'threaded_engine_create/3') :- !.
-user:prolog_predicate_name(user:'$lgt_threaded_engine_stop'(_, _), 'threaded_engine_stop/1') :- !.
+user:prolog_predicate_name(user:'$lgt_threaded_engine_destroy'(_, _), 'threaded_engine_destroy/1') :- !.
 user:prolog_predicate_name(user:'$lgt_threaded_engine_self'(_, _), 'threaded_engine_self/1') :- !.
 user:prolog_predicate_name(user:'$lgt_current_engine_'(_, _), 'threaded_engine/1') :- !.
-user:prolog_predicate_name(user:'$lgt_threaded_engine_answer'(_, _, _), 'threaded_engine_answer/2') :- !.
-user:prolog_predicate_name(user:'$lgt_threaded_engine_return'(_, _), 'threaded_engine_return/1') :- !.
+user:prolog_predicate_name(user:'$lgt_threaded_engine_next'(_, _, _), 'threaded_engine_next/2') :- !.
+user:prolog_predicate_name(user:'$lgt_threaded_engine_yield'(_, _), 'threaded_engine_yield/1') :- !.
 user:prolog_predicate_name(user:'$lgt_threaded_engine_post'(_, _, _), 'threaded_engine_post/2') :- !.
 user:prolog_predicate_name(user:'$lgt_threaded_engine_fetch'(_, _), 'threaded_engine_fetch/1') :- !.
 
