@@ -3,7 +3,7 @@
 #############################################################################
 ## 
 ##   Unit testing automation script
-##   Last updated on May 14, 2016
+##   Last updated on June 12, 2016
 ## 
 ##   This file is part of Logtalk <http://logtalk.org/>  
 ##   Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
@@ -27,7 +27,7 @@
 export LC_ALL=C
 
 print_version() {
-	echo "$(basename "$0") 0.11"
+	echo "$(basename "$0") 0.16"
 	exit 0
 }
 
@@ -115,10 +115,10 @@ run_tests() {
 		grep -a '(not applicable)' "$results/$name.results" | sed 's/(/*****         (/'
 	elif [ $tests_exit -eq 124 ] ; then
 		echo "*****         timeout"
-		echo "LOGTALK_TIMEOUT" > "$results/$name.errors"
+		echo "LOGTALK_TIMEOUT" >> "$results/$name.errors"
 	else
 		echo "*****         crash"
-		echo "LOGTALK_CRASH" > "$results/$name.errors"
+		echo "LOGTALK_CRASH" >> "$results/$name.errors"
 	fi
 	return 0
 }
@@ -149,7 +149,7 @@ usage_help()
 	echo "Optional arguments:"
 	echo "  -v print version of $(basename "$0")"
 	echo "  -p back-end Prolog compiler (default is $backend)"
-	echo "     (possible values are b, cx, eclipse, gnu, ji, lean, qp, sicstus, swi, xsb, xsbmt, and yap)"
+	echo "     (possible values are b, cx, eclipse, gnu, ji, lean, qp, sicstus, swi, swipack, xsb, xsbmt, and yap)"
 	echo "  -m compilation mode (default is $mode)"
 	echo "     (possible values are optimal, normal, debug, and all)"
 	echo "  -f format for writing the test results (default is $format)"
@@ -225,6 +225,10 @@ elif [ "$p_arg" == "swi" ] ; then
 	prolog='SWI-Prolog'
 	logtalk=swilgt$extension
 	logtalk_call="$logtalk -g"
+elif [ "$p_arg" == "swipack" ] ; then
+	prolog='SWI-Prolog'
+	logtalk=swipl
+	logtalk_call="$logtalk -g"
 elif [ "$p_arg" == "xsb" ] ; then
 	prolog='XSB'
 	logtalk=xsblgt$extension
@@ -288,6 +292,11 @@ elif [ "$f_arg" != "" ] ; then
 	exit 1
 fi
 
+if [ "$p_arg" == "swipack" ] ; then
+	versions_goal="use_module(library(logtalk)),$versions_goal"
+	format_goal="use_module(library(logtalk)),$format_goal"
+fi
+
 if [ "$d_arg" != "" ] ; then
 	results="$d_arg"
 fi
@@ -318,13 +327,17 @@ $logtalk_call $versions_goal > "$results"/tester_versions.txt 2> /dev/null
 grep -a "Logtalk version:" "$results"/tester_versions.txt
 grep -a "Prolog version:" "$results"/tester_versions.txt | sed "s/Prolog/$prolog/"
 
-find "$base" -name "tester.lgt" -or -name "tester.logtalk" | while read file; do
+testsets=0
+output="$(find "$base" -name "tester.lgt" -or -name "tester.logtalk")"
+while read file; do
+	((testsets++))
 	run_tests "$file"
-done
+done <<< "$output"
 
 cd "$results"
 timeouts=$(grep -a 'LOGTALK_TIMEOUT' *.errors | wc -l | sed 's/ //g')
 crashes=$(grep -a 'LOGTALK_CRASH' *.errors | wc -l | sed 's/ //g')
+testsetruns=$(($testsets-$timeouts-$crashes))
 skipped=$(grep -a ': skipped' *.results | wc -l | sed 's/ //g')
 passed=$(grep -a ': success' *.results | wc -l | sed 's/ //g')
 failed=$(grep -a ': failure' *.results | wc -l | sed 's/ //g')
@@ -357,8 +370,7 @@ echo "***** Failed tests"
 echo "*******************************************************************************"
 grep -a ': failure' *.results | sed 's/: failure//' | sed 's/.results:!     / - /' | sed 's|__|/|g' | sed "s|^$prefix||"
 echo "*******************************************************************************"
-echo "***** $timeouts test set timeouts"
-echo "***** $crashes test set crashes"
+echo "***** $testsets test sets: $testsetruns completed, $timeouts timeouts, $crashes crashes"
 echo "***** $total tests: $skipped skipped, $passed passed, $failed failed"
 echo "*******************************************************************************"
 
