@@ -1,10 +1,10 @@
 /////////////////////////////////////////////////////////////////////////////
 //
 //   XML documenting files to plain text conversion script 
-//   Last updated on November 3, 2014
+//   Last updated on February 17, 2016
 //
 //   This file is part of Logtalk <http://logtalk.org/>  
-//   Copyright 1998-2015 Paulo Moura <pmoura@logtalk.org>
+//   Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
 //   
 //   Licensed under the Apache License, Version 2.0 (the "License");
 //   you may not use this file except in compliance with the License.
@@ -66,7 +66,8 @@ else {
 	WScript.Quit(1);
 }
 
-var xslt = logtalk_user + "\\xml\\lgttxt.xsl";
+var entity_xslt = logtalk_user + "\\tools\\lgtdoc\\xml\\logtalk_entity_to_txt.xsl";
+var index_xslt = logtalk_user + "\\tools\\lgtdoc\\xml\\logtalk_index_to_txt.xsl";
 
 var d_arg = "";
 var p_arg = "";
@@ -93,20 +94,28 @@ if (p_arg != "" && p_arg != "msxsl" && p_arg != "xsltproc" && p_arg != "xalan" &
 } else if (p_arg != "")
 	processor = p_arg;
 
-if (!FSObject.FileExists(WshShell.CurrentDirectory + "\\logtalk.dtd")) {
-	FSObject.CopyFile(logtalk_home + "\\xml\\logtalk.dtd", WshShell.CurrentDirectory + "\\logtalk.dtd");
+if (!FSObject.FileExists(WshShell.CurrentDirectory + "\\logtalk_entity.dtd")) {
+	FSObject.CopyFile(logtalk_home + "\\tools\\lgtdoc\\xml\\logtalk_entity.dtd", WshShell.CurrentDirectory + "\\logtalk_entity.dtd");
+}
+
+if (!FSObject.FileExists(WshShell.CurrentDirectory + "\\logtalk_index.dtd")) {
+	FSObject.CopyFile(logtalk_home + "\\tools\\lgtdoc\\xml\\logtalk_index.dtd", WshShell.CurrentDirectory + "\\logtalk_index.dtd");
 }
 
 if (!FSObject.FileExists(WshShell.CurrentDirectory + "\\custom.ent")) {
-	FSObject.CopyFile(logtalk_home + "\\xml\\custom.ent", WshShell.CurrentDirectory + "\\custom.ent");
+	FSObject.CopyFile(logtalk_home + "\\tools\\lgtdoc\\xml\\custom.ent", WshShell.CurrentDirectory + "\\custom.ent");
 }
 
-if (!FSObject.FileExists(WshShell.CurrentDirectory + "\\logtalk.xsd")) {
-	FSObject.CopyFile(logtalk_home + "\\xml\\logtalk.xsd", WshShell.CurrentDirectory + "\\logtalk.xsd");
+if (!FSObject.FileExists(WshShell.CurrentDirectory + "\\logtalk_entity.xsd")) {
+	FSObject.CopyFile(logtalk_home + "\\tools\\lgtdoc\\xml\\logtalk_entity.xsd", WshShell.CurrentDirectory + "\\logtalk_entity.xsd");
+}
+
+if (!FSObject.FileExists(WshShell.CurrentDirectory + "\\logtalk_index.xsd")) {
+	FSObject.CopyFile(logtalk_home + "\\tools\\lgtdoc\\xml\\logtalk_index.xsd", WshShell.CurrentDirectory + "\\logtalk_index.xsd");
 }
 
 if (!FSObject.FileExists(directory + "\\logtalk.css")) {
-	FSObject.CopyFile(logtalk_user + "\\xml\\logtalk.css", directory + "\\logtalk.css");
+	FSObject.CopyFile(logtalk_user + "\\tools\\lgtdoc\\xml\\logtalk.css", directory + "\\logtalk.css");
 }
 
 WScript.Echo("");
@@ -116,9 +125,15 @@ var files = new Enumerator(FSObject.GetFolder(WshShell.CurrentDirectory).Files);
 
 for (files.moveFirst(); !files.atEnd(); files.moveNext()) {
 	var file = files.item().name;
+	var xslt;
 	if (FSObject.GetExtensionName(file) == "xml") {
 		WScript.Echo("  converting " + file);
 		var txt_file = directory + "\\" + FSObject.GetBaseName(file) + ".txt";
+		if (file == "directory_index.xml" || file == "entity_index.xml" || file == "predicate_index.xml") {
+			xslt = index_xslt;
+		} else {
+			xslt = entity_xslt;
+		}
 		switch (processor) {
 			case "msxsl" :
 				WshShell.Run("msxsl -o \"" + txt_file + "\" \"" + file + "\" \"" + xslt + "\"", true);
